You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@ponymail.apache.org by se...@apache.org on 2017/09/03 21:23:45 UTC

incubator-ponymail git commit: Rename 'redundant' generator as 'cluster'

Repository: incubator-ponymail
Updated Branches:
  refs/heads/master c038ec329 -> 4b6d7f771


Rename 'redundant' generator as 'cluster'

Project: http://git-wip-us.apache.org/repos/asf/incubator-ponymail/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-ponymail/commit/4b6d7f77
Tree: http://git-wip-us.apache.org/repos/asf/incubator-ponymail/tree/4b6d7f77
Diff: http://git-wip-us.apache.org/repos/asf/incubator-ponymail/diff/4b6d7f77

Branch: refs/heads/master
Commit: 4b6d7f7712f0a69d30e21180b326adcc639ddba5
Parents: c038ec3
Author: Sebb <se...@apache.org>
Authored: Sun Sep 3 22:23:41 2017 +0100
Committer: Sebb <se...@apache.org>
Committed: Sun Sep 3 22:23:41 2017 +0100

----------------------------------------------------------------------
 tools/archiver.py   |  4 ++--
 tools/generators.py | 10 +++++-----
 tools/setup.py      |  6 +++---
 3 files changed, 10 insertions(+), 10 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/incubator-ponymail/blob/4b6d7f77/tools/archiver.py
----------------------------------------------------------------------
diff --git a/tools/archiver.py b/tools/archiver.py
index 0966b13..f7eabfe 100755
--- a/tools/archiver.py
+++ b/tools/archiver.py
@@ -321,8 +321,8 @@ class Archiver(object):
                     mid = generators.full(msg, body, lid, attachments)
                 elif archiver_generator == "medium":
                     mid = generators.medium(msg, body, lid, attachments)
-                elif archiver_generator == "redundant":
-                    mid = generators.redundant(msg, body, lid, attachments)
+                elif archiver_generator == "cluster":
+                    mid = generators.cluster(msg, body, lid, attachments)
                 else:
                     mid = generators.legacy(msg, body, lid, attachments)
             except Exception as err:

http://git-wip-us.apache.org/repos/asf/incubator-ponymail/blob/4b6d7f77/tools/generators.py
----------------------------------------------------------------------
diff --git a/tools/setup.py b/tools/setup.py
index bf646fb..c5abab8 100755
--- a/tools/setup.py
+++ b/tools/setup.py
@@ -82,7 +82,7 @@ parser.add_argument('--noindex', dest='noi', action='store_true',
 parser.add_argument('--nocloud', dest='nwc', action='store_true', 
                    help='Do not enable word cloud')
 parser.add_argument('--generator', dest='generator', type=str, nargs=1,
-                   help='Document ID Generator to use (legacy, medium, redundant, full)')
+                   help='Document ID Generator to use (legacy, medium, cluster, full)')
 args = parser.parse_args()    
 
 print("Welcome to the Pony Mail setup script!")
@@ -113,7 +113,7 @@ if args.defaults:
     wce = True
     shards = 1
     replicas = 0
-    genname = "redundant"
+    genname = "cluster"
 
 # Accept CLI args, copy them
 if args.dbhost:
@@ -161,7 +161,7 @@ while wc == "":
         wce = True
 
 while genname == "":
-    gens = ['legacy', 'medium', 'redundant', 'full']
+    gens = ['legacy', 'medium', 'cluster', 'full']
     print ("Please select a document ID generator:")
     print("1  LEGACY: The original document generator for v/0.1-0.8 (no longer recommended)")
     print("2  MEDIUM: The medium comprehensive generator for v/0.9 (no longer recommended)")
diff --git a/tools/generators.py b/tools/generators.py
index aef9e77..1c578b3 100644
--- a/tools/generators.py
+++ b/tools/generators.py
@@ -45,7 +45,7 @@ def full(msg, body, lid, attachments):
     return mid
 
 # Medium: Standard 0.9 generator - Not recommended for future installations.
 # See 'full' or 'redundant' generators instead.
 def medium(msg, body, lid, attachments):
     """
     Standard 0.9 generator - Not recommended for future installations.
@@ -91,13 +91,13 @@ def medium(msg, body, lid, attachments):
     mid = "%s@%s" % (hashlib.sha224(xbody).hexdigest(), lid)
     return mid
 
-# Redundant: Use data that is guaranteed to be the same across redundant setups
-# This is the recommended generator for redundant cluster setups.
+# cluster: Use data that is guaranteed to be the same across cluster setups
+# This is the recommended generator for cluster setups.
 # Unlike 'medium', this only makes use of the Date: header and not the archived-at,
 # as the archived-at may change from node to node (and will change if not in the raw mbox file)
-def redundant(msg, body, lid, attachments):
+def cluster(msg, body, lid, attachments):
     """
     Use data that is guaranteed to be the same across redundant setups
     (does not guarantee to create unique ids)
 
     The following message fields are concatenated to form the hash input:

http://git-wip-us.apache.org/repos/asf/incubator-ponymail/blob/4b6d7f77/tools/setup.py
----------------------------------------------------------------------
@@ -45,7 +45,7 @@ def full(msg, body, lid, attachments):
 
 # Medium: Standard 0.9 generator - Not recommended for future installations.
-# See 'full' or 'redundant' generators instead.
+# See 'full' or 'cluster' generators instead.
 def medium(msg, body, lid, attachments):
     """
@@ -91,13 +91,13 @@ def medium(msg, body, lid, attachments):
     """
-    Use data that is guaranteed to be the same across redundant setups
+    Use data that is guaranteed to be the same across cluster setups
     (does not guarantee to create unique ids)
 